@@ -3,13 +3,13 @@ use warnings;
 
 package Dist::Zilla::MetaProvides::Types;
 BEGIN {
-  $Dist::Zilla::MetaProvides::Types::VERSION = '1.12044806';
+  $Dist::Zilla::MetaProvides::Types::VERSION = '1.12060212';
 }
 
 # ABSTRACT: Utility Types for the MetaProvides Plugin
 #
 # $Id:$
-use Moose ();
+# use Moose ();
 use MooseX::Types::Moose (':all');
 use MooseX::Types -declare => [ 'ModVersion', 'ProviderObject', ];
 
@@ -32,7 +32,7 @@ Dist::Zilla::MetaProvides::Types - Utility Types for the MetaProvides Plugin
 
 =head1 VERSION
 
-version 1.12044806
+version 1.12060212
 
 =head1 SUBTYPES
 
@@ -68,7 +68,7 @@ Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Kent Fredric.
+This software is copyright (c) 2011 by Kent Fredric.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
