@@ -3,7 +3,7 @@ use warnings;
 
 package Dist::Zilla::Role::MetaProvider::Provider;
 BEGIN {
-  $Dist::Zilla::Role::MetaProvider::Provider::VERSION = '1.12044806';
+  $Dist::Zilla::Role::MetaProvider::Provider::VERSION = '1.12060212';
 }
 
 # ABSTRACT: A Role for Metadata providers specific to the 'provider' key.
@@ -79,12 +79,12 @@ sub _apply_meta_noindex {
 
   my $meta = $self->_try_regen_metadata;
 
-  if ( not keys %$meta or not exists $meta->{no_index} ) {
-    $self->log_debug( "No no_index attribute found while trying to apply meta_noindex for" . $self->plugin_name );
+  if ( not keys %{$meta} or not exists $meta->{no_index} ) {
+    $self->log_debug( q{No no_index attribute found while trying to apply meta_noindex for} . $self->plugin_name );
     return @items;
   }
   else {
-    $self->log_debug("no_index found in metadata, will apply rules");
+    $self->log_debug(q{no_index found in metadata, will apply rules});
   }
 
   my $noindex = $meta->{'no_index'};
@@ -95,16 +95,18 @@ sub _apply_meta_noindex {
   $packages   = $noindex->{'package'}   if exists $noindex->{'package'};
   $namespaces = $noindex->{'namespace'} if exists $noindex->{'namespace'};
 
-  for my $file (@$files) {
+  for my $file (@{$files}) {
     @items = grep { $_->file ne $file } @items;
   }
-  for my $module (@$packages) {
+  for my $module (@{$packages}) {
     @items = grep { $_->module ne $module } @items;
   }
-  for my $dir (@$dirs) {
+  for my $dir (@{$dirs}) {
+    ## no critic (RegularExpressions ProhibitPunctuationVars)
     @items = grep { $_->file !~ qr{^\Q$dir\E($|/)} } @items;
   }
-  for my $namespace (@$namespaces) {
+  for my $namespace (@{$namespaces}) {
+    ## no critic (RegularExpressions ProhibitPunctuationVars)
     @items = grep { $_->module !~ qr{^\Q$namespace\E($|::)} } @items;
   }
   return @items;
@@ -121,7 +123,8 @@ sub metadata {
 }
 
 
-no Moose;
+no Moose::Role;
+
 1;
 
 
@@ -134,7 +137,7 @@ Dist::Zilla::Role::MetaProvider::Provider - A Role for Metadata providers specif
 
 =head1 VERSION
 
-version 1.12044806
+version 1.12060212
 
 =head1 PERFORMS ROLES
 
@@ -228,7 +231,7 @@ This is so C<{ version =E<gt> undef }> does not occur in the YAML.
 =head2 _try_regen_metadata
 
 This is a nasty hack really, to work around the way L<< C<Dist::Zilla>|Dist::Zilla >> handles
-metaproviders, which result in meta-data being inaccessabile to metadata Plugins.
+metaproviders, which result in meta-data being inaccessible to metadata Plugins.
 
   my $meta  = $object->_try_regen_metadata()
 
@@ -251,7 +254,7 @@ Returns either an empty list, or a list of ProvideRecord's
 
 =head2 metadata
 
-Fullfills the requirement of L<Dist::Zilla::Role::MetaProvider> by processing
+Fulfills the requirement of L<Dist::Zilla::Role::MetaProvider> by processing
 results returned from C<$self-E<gt>provides>.
 
 =head1 SEE ALSO
@@ -281,7 +284,7 @@ Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Kent Fredric.
+This software is copyright (c) 2011 by Kent Fredric.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
